close all;clear all;clc %#ok<CLALL>
A=xlsread('mastersheet.xlsx',1,'A2:Z521');
SZ=A(:,6);    % sample size
MTOT=A(:,7);  % mean TOT
SDTOT=A(:,8); % SD TOT
Age=A(:,9);   % participant age
TBTC=A(:,25); % time budget to collision
TBTB=A(:,26); % time budget to other boundaries
%% Figure 2. Distribution of 520 mean take-over times (TOTs) reported in the included studies. The bin width is 0.25 s.
xbins=0:.25:21;
figure;box on;grid on
bar(xbins+mean(diff(xbins))/2,histc(MTOT,xbins),'w','linewidth',2);
xlabel('Mean take-over time (s)');ylabel('Frequency')
set(gca,'xlim',[0 21],'xtick',0:1:21,'looseinset',[0.01 0.01 0.01 0.01],'tickdir','out');
h=findobj('fontname','helvetica');set(h,'fontsize',24,'fontname','arial')
%% Figure 3. Within-study effects. The circles represent the difference in mean take-over time between two conditions (D) of a particular study. A positive D indicates that a larger mean TOT was obtained from the latter condition compared to the former condition. The large square markers represent the average D in the category. k represents the number of studies (D values) in the category. p is the p-value from a two-sided signed rank test for the hypothesis that the D values come from a distribution having a median of 0. TOR = Take-over request, NDT = Non-driving task. A directional TOR is a TOR that is informative about the location of the hazard. Peripheral visual stimuli are stimuli that indicate the status of the automation or the environment (e.g., using ambient LEDs).
[~,~,raw]=xlsread('mastersheet.xlsx',2,'A2:H134');
INS=[find(cellfun(@length,raw(:,1))>1);size(raw,1)+1]; % indexes of comparisons
figure;hold on;grid on;box on;
for i=1:length(INS)-1
    temp=INS(i):INS(i+1)-1;
    plot(nanmean(cell2mat(raw(temp,8))),i,'rs','markersize',15,'linewidth',2)
    plot(cell2mat(raw(temp,5)),i,'ko','markersize',7,'linewidth',1.5)
    p=signrank(cell2mat(raw(temp,5)));
    if p<0.001;s='p < 0.001';else;s=['p = ' sprintf('%.3f',p)];end
    text(6.1,i,['Av. D = ' sprintf('%.2f',nanmean(cell2mat(raw(temp,8)))) ' s, k = ' sprintf('%.0f',nansum(~isnan(cell2mat(raw(temp,5))))) ', ' s])
end
plot([0 0],[-1 1000],'b:','linewidth',2)
xlabel('Difference in mean take-over time (D) (s)')
h=findobj('fontname','helvetica');set(h,'fontsize',20,'fontname','Arial')
set(gca,'looseinset',[0.01 0.01 0.24 0.01],'ytick',1:1000,'yticklabel',raw(INS(1:end-1),1),'ydir','reverse','ylim',[.5 length(INS)-.5])
%% Figure 4. Scatter plot of the standard deviation of the take-over time (SD TOT) as a function of the mean take-over time (mean TOT), with a fitted least-squares regression line (n = 397).
figure;hold on;grid on;box on
temp=(~isnan(MTOT)&~isnan(SDTOT));
plot([0 20],polyval(polyfit(MTOT(temp),SDTOT(temp),1),[0 20]),'r:','linewidth',2)
plot(MTOT(temp),SDTOT(temp),'ko','linewidth',2,'markersize',12);hold on
xlabel('Mean take-over time (s)');ylabel('Standard deviation of take-over time (s)')
h=findobj('fontname','Helvetica');set(h,'fontsize',26,'fontname','Arial')
set(gca,'looseinset',[0.01 0.01 0.01 0.01],'xlim',[0 20],'ylim',[0 10])
disp(['Number of markers in the MTOT vs. SDTOT plot = ' num2str(sum(temp))])
%% Figure 5. Scatter plot of the mean take-over time (mean TOT) as a function of a) mean age of the participant group (n = 485), b) take-over time budget to collision (TBTC, n = 240), c) take-over time budget to other boundaries (TBTB, n = 160), with a fitted least-squares regression line. A TBTB of 0 s means that the automation was deactivated at the moment of the take-over stimulus.
figure;
subplot(1,3,1)
temp=~isnan(Age)&~isnan(MTOT);
plot(Age(temp),MTOT(temp),'ko','linewidth',2,'markersize',10);hold on;grid on
plot([0 200],polyval(polyfit(Age(temp),MTOT(temp),1),[0 200]),'r:','linewidth',2)
set(gca,'Position',[0.05 0.11 0.27 0.85])
xlabel('Mean age (years)');ylabel('Mean take-over time (s)')
disp(['Number of markers in the Age vs MTOT plot = ' num2str(sum(temp))])
set(gca,'looseinset', [0.01 0.01 0.10 0.01],'xlim',[17 75],'ylim',[0 10],'ytick',0:1:10)

subplot(1,3,2)
temp=~isnan(TBTC)&~isnan(MTOT);
plot(TBTC(temp),MTOT(temp),'ko','linewidth',2,'markersize',10);hold on;grid on
disp(['Number of markers in the TBTC vs MTOT plot = ' num2str(sum(temp))])
plot([0 200],polyval(polyfit(TBTC(temp),MTOT(temp),1),[0 200]),'r:','linewidth',2)
set(gca,'position',[0.38 0.11 0.27 0.85])
xlabel('Time budget to collision (TBTC) (s)')
set(gca,'looseinset',[0.01 0.01 0.10 0.01],'xlim',[0 30],'ylim',[0 9],'ytick',0:1:9)

subplot(1,3,3)
temp=~isnan(TBTB)&~isnan(MTOT);
plot(TBTB(temp),MTOT(temp),'ko','linewidth',2,'markersize',10);hold on;grid on
disp(['Number of markers in the TBTB vs MTOT plot = ' num2str(sum(temp))])
plot([0 200],polyval(polyfit(TBTB(temp),MTOT(temp),1),[0 200]),'r:','linewidth',2)
set(gca,'Position',[0.71 0.11 0.27 0.85])
xlabel('Time budget to boundary (TBTB) (s)')
h=findobj('fontname','Helvetica'); set(h,'fontsize',22,'fontname','Arial')
set(gca,'looseinset',[0.01 0.01 0.10 0.01],'xlim',[0 60],'ylim',[0 20],'ytick',0:2:20)
%% Figure 6. Scatter plot of the sample size of the participant group as a function of the corresponding mean take-over time (mean TOT), with a fitted least-squares regression line (n = 520). The vertical line represents the grand mean TOT.
figure;hold on;grid on;box on
temp=(~isnan(SZ)&~isnan(MTOT));
plot([0 20],polyval(polyfit(MTOT(temp),SZ(temp),1),[0 20]),'r:','linewidth',2)
plot(MTOT(temp),SZ(temp),'ko','linewidth',2,'markersize',12);hold on
plot([mean(MTOT) 0],[-1 1000000],'b--','linewidth',2)
xlabel('Mean take-over time (s)');ylabel('Sample size')
set(gca, 'LooseInset', [0.01 0.01 0.01 0.01],'ylim',[0 120],'xlim',[0 20])
disp(['Number of markers in the MTOT vs. SZ plot = ' num2str(sum(temp))])
h=findobj('fontname','Helvetica'); set(h,'fontsize',26,'fontname','Arial')
%% Table 3. Spearman rank-order correlations between the predictor variables shown in Table 2
rho=corr(A(:,[9:11 18:21 12:17 24 22 23 25 26]),'rows','pairwise','type','spearman');disp(tril(round(rho,2)))
%% Table 2. Correlations between the study variables and mean TOTs in the between-study analysis. Pearson product-moment correlations and Spearman rank-order correlations are reported
d=A(:,[9:11 18:21 12:17 24 22 23 25 26]);
[Table2M,Table2SD,Table2N]=deal(NaN(size(d,2),3));

disp([transpose(1:18) round([corr(d,MTOT,'rows','pairwise') corr(d,MTOT,'rows','pairwise','type','spearman')],2)])

for t=0:2 % loop over the coding levels
    for i=1:size(d,2) % loop over the 18 variables
        if ismember(i,[1 17 18]) % for these continuous variables only the N is reported, as no coding levels are available 
            Table2N(i,t+1)=sum(d(:,i)>=0);
        else
            Table2M(i,t+1)=mean(MTOT(d(:,i)==t));Table2SD(i,t+1)=std(MTOT(d(:,i)==t));Table2N(i,t+1)=sum(d(:,i)==t); % Mean, SD, and number of mean TOT values for coding level t
        end
    end
end
disp([transpose(1:18) Table2N round(Table2M,2)])
disp([transpose(1:18) round(Table2M,2)])
disp([transpose(1:18) round(Table2SD,2)])
%%
disp('Pearson correlations with sample size, Spearman correlation with sample size, and number of available mean TOT values')
disp([transpose(1:18) round([corr(d,SZ,'rows','pairwise') corr(d,SZ,'rows','pairwise','type','spearman')],2) sum(~isnan(d))'])